==> nui_form-0.0.14.tar.gz: lib/component/nuif_checkgroup.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_form/component/nuif_checkbox.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIFCheckGroupItem extends NUIFormContainer{
  NUIFCheckGroupItem({
    @required List<NUIFCheckboxItem> items,
    @required String inpId,
    this.divider:0.0,
    this.padding,
    double width,
    double height,
    Alignment align,
    EdgeInsets margin,
    this.enabledStyle,
    this.isHorizontal : false,
    this.disabledStyle,
    double weight}): super(items: items, inpId : inpId, inpType: ComponentType.CHECKGROUP, width: width, height: height, weight: weight, margin: margin, align: align);
  double divider;
  EdgeInsets padding;
  bool isHorizontal;
  NUIFCheckboxStyle enabledStyle;
  NUIFCheckboxStyle disabledStyle;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCheckGroupLayout(item: this, key: key, allItemSelectListener: allItemSelectListener,);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    List<NUIFormSelection> selectedValues = List();
    items.forEach((comp) {
      final item = (comp as NUIFCheckboxItem).getValue();
      if(item != null){
        selectedValues.add(item.value);
      }
    });

    final groupValue = NUIFormValue(
        inpId: inpId,
        values: selectedValues
    );
    map[inpId] = groupValue;
  }
}

class NUIFCheckGroupLayout extends StatefulWidget {
  NUIFCheckGroupLayout({@required this.item, this.allItemSelectListener, Key key}): super(key: key);
  final NUIFCheckGroupItem item;
  final AllItemSelectListener allItemSelectListener;

  @override
  _NUIFCheckGroupLayoutState createState() => _NUIFCheckGroupLayoutState();
}

class _NUIFCheckGroupLayoutState extends NUIFState<NUIFCheckGroupLayout, NUIFCheckGroupItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: comp.toWidget(allTextChangeListener: null, allItemSelectListener: widget.allItemSelectListener, key: widget.key),
      width: comp.width,
      height: comp.height,
    );
  }

  List<Widget> _renderAllComponents(List<NUIFormComponent> items, double divider){
    List<Widget> views = List();
    bool addDivider = divider != null && divider > 0;
    NUICodeUtil.loop(items, (data, position, isFirst, isLast) {
      if(data is NUIFCheckboxItem){
        data.enabledStyle = data.enabledStyle ?? widget.item.enabledStyle;
        data.disabledStyle = data.disabledStyle ?? widget.item.disabledStyle;
      }

      if(!isFirst && addDivider){
        views.add(Divider(height: widget.item.divider ?? 0, thickness: 0, color: Colors.transparent,));
      }
      views.add(_renderComponent(data));
    });
    return views;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: item.padding,
      alignment: widget.item.align ?? Alignment.centerLeft,
      child: !widget.item.isHorizontal ? Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        key: widget.key,
        mainAxisSize: MainAxisSize.min,
        children: _renderAllComponents(item.items, item.divider),
      ) : Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        key: widget.key,
        mainAxisSize: MainAxisSize.min,
        children: _renderAllComponents(item.items, item.divider),
      ),
    );
  }
}

==> nui_form-0.0.36.tar.gz: lib/component/nuif_checkgroup.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_form/component/nuif_checkbox.dart';
import 'package:nui_form/nuif_form.dart';
import 'package:nui_form/nuif_form_component.dart';
import 'package:nui_core/code/nui_code_util.dart';

class NUIFCheckGroupItem extends NUIFormContainer{
  NUIFCheckGroupItem({
    List<NUIFCheckboxItem> items,
    this.selections,
    @required String inpId,
    this.divider:0.0,
    this.padding,
    double width,
    double height,
    Alignment align,
    EdgeInsets margin,
    this.enabledStyle,
    this.isHorizontal : false,
    this.disabledStyle,
    double weight}): super(items: items, inpId : inpId, inpType: ComponentType.CHECKGROUP, width: width, height: height, weight: weight, margin: margin, align: align);
  double divider;
  EdgeInsets padding;
  bool isHorizontal;
  NUIFCheckboxStyle enabledStyle;
  NUIFCheckboxStyle disabledStyle;
  List<NUIFSelection> selections;

  @override
  Widget toWidget({AllButtonClickListener allButtonClickListener, AllTextChangeListener allTextChangeListener, AllItemSelectListener allItemSelectListener, Key key}) {
    return NUIFCheckGroupLayout(item: this, key: key, allItemSelectListener: allItemSelectListener,);
  }

  @override
  void extractValue(Map<String, NUIFormValue> map){
    List<NUIFormSelection> selectedValues = List();
    items.forEach((comp) {
      final item = (comp as NUIFCheckboxItem).getValue();
      if(item != null){
        selectedValues.add(item.value);
      }
    });

    final groupValue = NUIFormValue(
        inpId: inpId,
        values: selectedValues
    );
    map[inpId] = groupValue;
  }
}

class NUIFCheckGroupLayout extends StatefulWidget {
  NUIFCheckGroupLayout({@required this.item, this.allItemSelectListener, Key key}): super(key: key);
  final NUIFCheckGroupItem item;
  final AllItemSelectListener allItemSelectListener;

  @override
  _NUIFCheckGroupLayoutState createState() => _NUIFCheckGroupLayoutState();
}

class _NUIFCheckGroupLayoutState extends NUIFState<NUIFCheckGroupLayout, NUIFCheckGroupItem> {

  @override
  void initState(){
    this.item = widget.item;
    super.initState();
  }

  Widget _renderComponent(NUIFormComponent comp){
    return Container(
      child: comp.toWidget(allTextChangeListener: null, allItemSelectListener: widget.allItemSelectListener, key: widget.key),
      width: comp.width,
      height: comp.height,
    );
  }

  List<NUIFCheckboxItem> _renderComponentsFromSelection(List<NUIFSelection> selections){
    return selections.map((e) {
      return NUIFCheckboxItem(inpId: e.getId(), selection: e, enabled: e.selectable(), enabledStyle: widget.item.enabledStyle, disabledStyle: widget.item.disabledStyle);
    }).toList();
  }

  List<Widget> _renderAllComponents(List<NUIFormComponent> items, double divider){
    List<Widget> views = List();
    bool addDivider = divider != null && divider > 0;
    NUICodeUtil.loop(items, (data, position, isFirst, isLast) {
      if(data is NUIFCheckboxItem){
        data.enabledStyle = data.enabledStyle ?? widget.item.enabledStyle;
        data.disabledStyle = data.disabledStyle ?? widget.item.disabledStyle;
      }

      if(!isFirst && addDivider){
        views.add(Divider(height: widget.item.divider ?? 0, thickness: 0, color: Colors.transparent,));
      }
      views.add(_renderComponent(data));
    });
    return views;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: item.padding,
      alignment: widget.item.align ?? Alignment.centerLeft,
      child: !widget.item.isHorizontal ? Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        key: widget.key,
        mainAxisSize: MainAxisSize.min,
        children: _renderAllComponents(item.items ?? _renderComponentsFromSelection(item.selections), item.divider),
      ) : Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        key: widget.key,
        mainAxisSize: MainAxisSize.min,
        children: _renderAllComponents(item.items ?? _renderComponentsFromSelection(item.selections), item.divider)
      ),
    );
  }
}
